marktools.Annotation
====================

.. abjad-lineage:: abjad.tools.marktools.Annotation.Annotation.Annotation

.. autoclass:: abjad.tools.marktools.Annotation.Annotation.Annotation
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.name
   :noindex:

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.value
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.attach
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__delattr__
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__ge__
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__gt__
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__le__
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__lt__
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__repr__
   :noindex:
